Struct amazon_sp_aplus_content::models::search_content_documents_response::SearchContentDocumentsResponse
source · [−]pub struct SearchContentDocumentsResponse {
pub warnings: Option<Vec<Error>>,
pub next_page_token: Option<String>,
pub content_metadata_records: Vec<ContentMetadataRecord>,
}Fields
warnings: Option<Vec<Error>>A set of messages to the user, such as warnings or comments.
next_page_token: Option<String>A page token that is returned when the results of the call exceed the page size. To get another page of results, call the operation again, passing in this value with the pageToken parameter.
content_metadata_records: Vec<ContentMetadataRecord>A list of A+ Content metadata records.
Implementations
sourceimpl SearchContentDocumentsResponse
impl SearchContentDocumentsResponse
pub fn new(
content_metadata_records: Vec<ContentMetadataRecord>
) -> SearchContentDocumentsResponse